@@ -36,7 +36,7 @@ from __future__ import unicode_literals
 
 # Will be parsed by setup.py to determine package metadata
 __author__ = 'Stefan Kögl <stefan@skoegl.net>'
-__version__ = '1.2'
+__version__ = '1.3'
 __website__ = 'https://github.com/stefankoegl/python-json-pointer'
 __license__ = 'Modified BSD License'
 
@@ -247,6 +247,15 @@ class JsonPointer(object):
         return len(self.parts) > len(ptr.parts) and \
              self.parts[:len(ptr.parts)] == ptr.parts
 
+    @property
+    def path(self):
+        """ Returns the string representation of the pointer
+
+        >>> ptr = JsonPointer('/~0/0/~1').path == '/~0/0/~1'
+        """
+        parts = [part.replace('~', '~0') for part in self.parts]
+        parts = [part.replace('/', '~1') for part in parts]
+        return '/' + '/'.join(parts)
 
     def __eq__(self, other):
         """ compares a pointer to another object
@@ -264,6 +273,20 @@ class JsonPointer(object):
     def __hash__(self):
         return hash(tuple(self.parts))
 
+    @classmethod
+    def from_parts(cls, parts):
+        """ Constructs a JsonPointer from a list of (unescaped) paths
+
+        >>> JsonPointer.from_parts(['a', '~', '/', 0]).path == '/a/~0/~1/0'
+        True
+        """
+        parts = [str(part) for part in parts]
+        parts = [part.replace('~', '~0') for part in parts]
+        parts = [part.replace('/', '~1') for part in parts]
+        ptr = cls('/' + '/'.join(parts))
+        return ptr
+
+
 
 def pairwise(iterable):
     """ s -> (s0,s1), (s1,s2), (s2, s3), ...
